<?php

/**
* The dashboard-specific functionality of the plugin.
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Conversation_Builder
* @subpackage 	Alexandria_Conversation_Builder/admin
*/

class Alexandria_Conversation_Builder_Settings_Fields {

	/**
	 * The plugin options.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$options    The plugin options.
	 */
	private $options;

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->set_options();

	}

	/**
	* Sets the class variable $options
	*
	* @since 		1.0.0
	*/
	private function set_options() {

		if ( get_option( $this->plugin_name.'_sender_mail' ) === false ){

			if( get_option( $this->plugin_name.'_admin_conversation' ) === false ){
				update_option( $this->plugin_name.'_sender_mail', get_option( $this->plugin_name.'_admin_conversation' ) );
			}
		}

		if ( get_option( $this->plugin_name.'_subject_mail' ) === false ){
			update_option( $this->plugin_name.'_subject_mail', 'Alexandria Conversation Builder' );
		}

		if ( get_option( $this->plugin_name.'_header_background_image_url' ) === false ){
			update_option( $this->plugin_name.'_header_background_image_url', ALEXANDRIA_CONVERSATION_PUBLIC_URL.'assets/images/landing_header.jpg' );
		}

		if ( get_option( $this->plugin_name.'_message_mail' ) === false ){
			update_option( $this->plugin_name.'_message_mail', 'Email ejemplo' );
		}

		if ( get_option( $this->plugin_name.'_button_text' ) === false ){
			update_option( $this->plugin_name.'_button_text', 'Construye Conversación');
		}

		if ( get_option( $this->plugin_name.'_titulo_portada' ) === false ){
			update_option( $this->plugin_name.'_titulo_portada', 'CONVERSATION BUILDER');
		}

		if ( get_option( $this->plugin_name.'_subtitulo_portada' ) === false ){
			update_option( $this->plugin_name.'_subtitulo_portada', 'Construye tu conversación');
		}

		if ( get_option( $this->plugin_name.'_descripcion_portada' ) === false ){
			update_option( $this->plugin_name.'_descripcion_portada', 'Construye tu email desafiante con sólo 3 inputs: dinos con quién debes hablar, sobre qué tema y cómo te sientes. Te ofreceremos una guía sobre cuál debe de ser tu objetivo, y herramientas muy concretas para iniciar la conversación, hacer buenas preguntas, seleccionar los argumentos que podrías utilizar para ser convincente, y qué cosas deberías de evitar para que dicha conversación sea lo más eficiente y humana posible.');
		}

		if ( get_option( $this->plugin_name.'_contact_type' ) === false ){
			update_option( $this->plugin_name.'_contact_type', 'custom_form' );
		}

	} // set_options()

	/**
	* Contact Form Type Field
	*
	* @since 		1.0.0
	*/
	public function contact_form_type_setting()
	{
		$plugin_name = $this->plugin_name;
		$option = get_option( $plugin_name.'_contact_type' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<fieldset>
				<input type="radio" class="contact_type" name="<?php echo $plugin_name .'-main-settings['.$plugin_name.'_contact_type]' ?>" id="custom_form" <?php echo $option == "custom_form" ? 'checked="checked"' : '' ?> value="custom_form" />
				<label for="custom_form"><?php _e('Formulario por defecto del plugin', 'alexandria-mail-builder'); ?></label>
				<input type="radio" class="contact_type" name="<?php echo $plugin_name .'-main-settings['.$plugin_name.'_contact_type]' ?>" id="contact_form_7" <?php echo $option == "contact_form_7" ? 'checked="checked"' : '' ?> value="contact_form_7"/>
				<label for="custom_form"><?php _e('Usar Plugin Contact Form 7', 'alexandria-mail-builder'); ?></label>
				<p class="description"><?php _e('Debes tener instalado y activado el Plugin de Contact Form 7. Si no lo tienes instalado puedes hacerlo en el siguiente enlace.', 'alexandria-mail-builder'); ?><a href="https://es.wordpress.org/plugins/contact-form-7/"><? _e('Contact Form 7', 'alexandria-mail-builder'); ?></a></p>
			</fieldset>

			<p class="description"></p>
		</p>

		<?php 
	}

	/**
	* Contact Form ID Field
	*
	* @since 		1.0.0
	*/
	public function contact_form_id_setting() {

		$args = array(
			'post_type' => 'wpcf7_contact_form', 
			'posts_per_page' => -1
		);

		$cf7Forms = get_posts( $args );

		if(function_exists('icl_object_id')) {

			$languages = apply_filters( 'wpml_active_languages', NULL, 'orderby=id&order=desc' );

			if ( !empty( $languages ) ) {

				foreach( $languages as $lang ) {

					$option = get_option(  $this->plugin_name.'_contact_form_id_'.$lang['language_code'] );
					$value = (!isset($option)) ? '' : $option;

					?>

					<div class="select-item" style="margin-bottom: 15px;">

						<img src="<?php echo $lang['country_flag_url']; ?>" alt=""/>

						<select name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_contact_form_id_'.esc_attr( $lang['language_code'] ).']' ?>" id="contact_form_id_select_<?php echo esc_attr( $lang['language_code'] ); ?>">

							<option value="0"><?php _e('Seleccionar Formulario', 'alexandria-conversation-builder') ?></option>

							<?php

							foreach ($cf7Forms as $key => $form) { ?>

								<option value="<?php echo $form->ID; ?>" <?php echo $form->ID == $value ? 'selected' : '' ?>><?php echo $form->post_title; ?></option>

							<?php } ?>

						</select>

					</div>

				<?php } ?>

				<p class="description"><?php _e('Seleccionar el formulario para cada idioma creado previamente en el plugin de contact form 7.', 'alexandria-conversation-builder'); ?></p>

				<?php
			}

		} else {

			$option = get_option(  $this->plugin_name.'_contact_form_id' );
			$value = (!isset($option)) ? '' : $option;

			?>

			<select name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_contact_form_id]' ?>" id="contact_form_id_select">

				<option value="0"><?php _e('Seleccionar Formulario', 'alexandria-conversation-builder') ?></option>

				<?php

				foreach ($cf7Forms as $key => $form) { ?>

					<option value="<?php echo $form->ID; ?>" <?php echo $form->ID == $value ? 'selected' : '' ?>><?php echo $form->post_title; ?></option>

				<?php } ?>

			</select>

			<p class="description"><?php _e('Seleccionar el formulario creado previamente en el plugin de contact form 7.', 'alexandria-conversation-builder'); ?></p>

			<?php
		}
	}

	/**
	* E-Mail Sender Field
	*
	* @since 		1.0.0
	*/
	public function sender_mail_setting() {

		$option = get_option(  $this->plugin_name.'_sender_mail' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p class="custom_form_item">
			<input type="email" id="sender_mail" name="<?php echo $this->plugin_name .'-main-settings['. $this->plugin_name.'_sender_mail]' ?>" value="<?php echo $value ?>" size='40' />
			<p class="description"><?php _e('Si se deja vacío, el formulario utiliza el correo electrónico configurado en los', 'alexandria-mail-builder'); ?> <a href="/wp-admin/options-general.php"><?php _e('General Settings')?></a></p>
		</p>

		<?php
	}

	/**
	* E-Mail Subject Field
	*
	* @since 		1.0.0
	*/
	public function subject_mail_setting() {

		$option = get_option(  $this->plugin_name.'_subject_mail' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p class="custom_form_item">
			<input type="text" id="subject_mail" name="<?php echo $this->plugin_name .'-main-settings['. $this->plugin_name.'_subject_mail]' ?>" value="<?php echo $value ?>" size='75' />
		</p>

		<?php
	}


	/**
	* E-Mail Message Field
	*
	* @since 		1.0.0
	*/
	public function message_mail_setting() {

		$option = get_option(  $this->plugin_name.'_message_mail' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p class="custom_form_item">
			<?php echo wp_editor($value, $this->plugin_name .'-main-settings-message_mail')?>
			<p class="description"><?php _e('Variables que se pueden utilizar {{full_name}} {{email}} {{message}}', 'alexandria-mail-builder'); ?></p>
		</p>

		<?php
	}

	/**
	* Header Background Image Field
	*
	* @since 		1.0.0
	*/
	public function header_background_image()
	{

		$image_id = get_option(  $this->plugin_name.'_header_background_image_id' );

		if($image = wp_get_attachment_image_src( $image_id )) { ?>

			<p>
				<a href="#" class="alexandria-conversation-builder-upl button">
					<img src="' . $image[0] . '" />
				</a>
				<input type="hidden" name="<?php echo $this->plugin_name .'-main-settings['. $this->plugin_name.'_header_background_image_id]' ?>" value="' . $image_id . '" />
				<a href="#" class="alexandria-conversation-builder-rmv button">
					<?php _e('Eliminar Imagen','alexandria-conversation-builder'); ?>
				</a>
			</p>    

			<?php

		} else {

			?>

			<p>
				<a href="#" class="alexandria-conversation-builder-upl button">
					<?php _e('Subir Imagen','alexandria-conversation-builder'); ?>
				</a>
				<input type="hidden" name="<?php echo $this->plugin_name .'-main-settings['. $this->plugin_name.'_header_background_image_id]' ?>" value="" />
				<a href="#" class="alexandria-conversation-builder-rmv button" style="display:none">
					<?php _e('Eliminar Imagen','alexandria-conversation-builder'); ?>
				</a>	
			</p>    

			<?php
		}
	}

	/**
	* Button make conversation background-color field
	*
	* @since 		1.0.0
	*/
	public function button_bg_color()
	{
		$option = get_option( $this->plugin_name.'_button_bg_color' );
		$value = (!isset($option)) ? '#000' : $option;

		?>

		<p>
			<input type="text" id="button_bg_color" value="<?php echo $value ?>" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_bg_color]' ?>" data-default-color="#000" class="color-field"/>
			<p class="description"></p>
		</p>

		<?php
	}

	/**
	* Button make conversation background-color hover field
	*
	* @since 		1.0.0
	*/
	public function button_bg_hover_color()
	{

		$option = get_option( $this->plugin_name.'_button_bg_hover_color' );
		$value = (!isset($option)) ? '#000' : $option;

		?>

		<p>
			<input type="text" id="button_bg_hover_color" value="<?php echo $value ?>" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_bg_hover_color]' ?>" data-default-color="#000" class="color-field"/>
			<p class="description"></p>
		</p>

		<?php
	}

	/**
	* Button make conversation text color field
	*
	* @since 		1.0.0
	*/
	public function button_text_color()
	{

		$option = get_option( $this->plugin_name.'_button_text_color' );
		$value = (!isset($option)) ? '#FFF' : $option;

		?>

		<p>
			<input type="text" id="button_text_color" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_text_color]' ?>" value="<?php echo $value ?>" data-default-color="#FFF" class="color-field"/>
		</p>

		<?php
	}


	/**
	* Button make conversation text color hover field
	*
	* @since 		1.0.0
	*/
	public function button_text_hover_color()
	{

		$option = get_option( $this->plugin_name .'_button_text_hover_color' );
		$value = (!isset($option)) ? '#FFF' : $option;

		?>

		<p>
			<input type="text" id="button_text_hover_color" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name .'_button_text_hover_color]' ?>" value="<?php echo $value ?>" data-default-color="#FFF" class="color-field"/>
		</p>

		<?php
	}

	/**
	* Button make email text field
	*
	* @since 		1.0.0
	*/
	public function button_text()
	{

		$option = get_option( $this->plugin_name.'_button_text' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<input type="text" id="button_text" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_text]' ?>" value="<?php echo $value ?>" size='40' />
		</p>

		<?php
	}

	/**
	* Button make email border-color field
	*
	* @since 		1.0.0
	*/
	public function button_border_color()
	{

		$option = get_option( $this->plugin_name.'_button_border_color' );
		$value = (!isset($option)) ? '#000000' : $option;

		?>

		<p>
			<input type="text" id="button_border_color" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_border_color]' ?>" value="<?php echo $value ?>" data-default-color="#000000" class="color-field"/>
		</p>

		<?php
	}


	/**
	* Button make email border-color hover field
	*
	* @since 		1.0.0
	*/
	public function button_border_hover_color()
	{

		$option = get_option( $this->plugin_name.'_button_border_hover_color' );
		$value = (!isset($option)) ? '#000000' : $option;

		?>

		<p>
			<input type="text" id="button_border_hover_color" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_button_border_hover_color]' ?>" value="<?php echo $value ?>" data-default-color="#000000" class="color-field"/>
		</p>

		<?php
	}


	/**
	* Builder Cover Title 
	*
	* @since 		1.0.0
	*/
	public function titulo_portada()
	{
		$option = get_option( $this->plugin_name.'_titulo_portada' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<input type="text" id="titulo_portada" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_titulo_portada]'; ?>" value="<?php echo $value ?>" size='75' />
		</p>

		<?php
	}


	/**
	* Builder Cover Subtitle 
	*
	* @since 		1.0.0
	*/
	public function subtitulo_portada()
	{

		$option = get_option( $this->plugin_name.'_subtitulo_portada' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<input type="text" id="subtitulo_portada" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_subtitulo_portada]'; ?>" value="<?php echo $value ?>" size='75' />
		</p>

		<?php
	}


	/**
	* Builder Cover Description
	*
	* @since 		1.0.0
	*/
	public function descripcion_portada()
	{

		$option = get_option( $this->plugin_name.'_descripcion_portada' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<?php echo wp_editor($value, $this->plugin_name .'-main-settings-descripcion_portada')?>
		</p>

		<?php
	}


	/**
	* Builder Cover Time
	*
	* @since 		1.0.0
	*/
	public function tiempo_portada()
	{
		$option = get_option( $this->plugin_name.'_tiempo_portada' );
		$value = (!isset($option)) ? '' : $option;

		?>

		<p>
			<input type="time" id="tiempo_portada" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_tiempo_portada]'; ?>" value="<?php echo $value ?>" size='75' />
		</p>

		<?php
	}


	/**
	* Cover header background-color
	*
	* @since 		1.0.0
	*/
	public function color_barra_cabecera_interior()
	{
		$option = get_option( $this->plugin_name.'_color_barra_cabecera_interior' );
		$value = (!isset($option)) ? '#000000' : $option;

		?>

		<p>
			<input type="text" id="color_barra_cabecera_interior" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_color_barra_cabecera_interior]' ?>" value="<?php echo $value ?>" data-default-color="#000000" class="color-field"/>
		</p>

		<?php
	}


	/**
	* Cover header background-color
	*
	* @since 		1.0.0
	*/
	public function texto_barra_cabecera_interior()
	{
		$option = get_option( $this->plugin_name.'_texto_barra_cabecera_interior' );
		$value = (!isset($option)) ? '#000000' : $option;

		?>

		<p>
			<input type="text" id="texto_barra_cabecera_interior" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_texto_barra_cabecera_interior]' ?>" value="<?php echo $value ?>"/>
		</p>

		<?php
	}


	/**
	* Cover header text color
	*
	* @since 		1.0.0
	*/
	public function color_texto_barra_cabecera_interior()
	{
		$option = get_option( $this->plugin_name.'_color_texto_barra_cabecera_interior' );
		$value = (!isset($option)) ? '#000000' : $option;

		?>

		<p>
			<input type="text" id="color_texto_barra_cabecera_interior" name="<?php echo $this->plugin_name .'-main-settings['.$this->plugin_name.'_color_texto_barra_cabecera_interior]' ?>" value="<?php echo $value ?>" data-default-color="#000000" class="color-field"/>
		</p>

		<?php
	}

	/**
	* Registers settings sections with WordPress
	*
	* @since 		1.0.0
	*/
	public function register_settings_sections() {

		// add_settings_field( $field_id, $field_title, $field_callback, $page_name, $section_name );

		add_settings_section(
			'general_fields_setting_section',
			__( 'Página Principal', 'alexandria-mail-builder' ),
			array( $this, 'print_general_section_info' ),
			$this->plugin_name . '-settings',
			$this->plugin_name . '-option-group'
		);

		add_settings_section(
			'style_fields_setting_section',
			__( 'Estilos Builder', 'alexandria-mail-builder' ),
			array( $this, 'print_section_info' ),
			$this->plugin_name . '-styles',
			$this->plugin_name . '-option-group'
		);

		add_settings_section(
			'button_style_fields_setting_section',
			__( 'Estilos Botón - Construir E-Mail', 'alexandria-mail-builder' ),
			array( $this, 'print_section_info' ),
			$this->plugin_name . '-styles',
			$this->plugin_name . '-option-group'
		);

		add_settings_section(
			'contact_form_type_setting_section',
			__( 'Formulario de Contacto', 'alexandria-mail-builder' ),
			array( $this, 'print_section_info' ),
			$this->plugin_name . '-contact-type',
			$this->plugin_name . '-option-group'
		);

		add_settings_section(
			'custom_contact_form_setting_section',
			__( 'Formulario de Contacto', 'alexandria-mail-builder' ),
			array( $this, 'print_section_info' ),
			$this->plugin_name . '-contact',
			$this->plugin_name . '-option-group'
		);

		add_settings_section(
			'contact_form_setting_section',
			__( 'Formulario de Contacto - Contact Form 7', 'alexandria-mail-builder' ),
			array( $this, 'print_contact_form_seven_info' ),
			$this->plugin_name . '-contact-form-7',
			$this->plugin_name . '-option-group'
		);

	}

	/**
	 * Registers settings fields with WordPress
	 *
	 * @since 		1.0.0
	 */
	public function register_settings_fields() {

		add_settings_field(
			'cover_image',
			__( 'Imagen Portada', $this->plugin_name ),
			array( $this, 'header_background_image' ),
			$this->plugin_name . '-settings',
			'general_fields_setting_section',
			$this->plugin_name . '-option-group'         
		);

		add_settings_field(
			$this->plugin_name.'_titulo_portada',
			__( 'Título Portada', 'alexandria-mail-builder' ),
			array( $this, 'titulo_portada' ),
			$this->plugin_name . '-settings',
			'general_fields_setting_section',
			$this->plugin_name . '-option-group'              
		);

		add_settings_field(
			$this->plugin_name.'_subtitulo_portada',
			__( 'Subtítulo Portada', 'alexandria-mail-builder' ),
			array( $this, 'subtitulo_portada' ),
			$this->plugin_name . '-settings',
			'general_fields_setting_section',
			$this->plugin_name . '-option-group'              
		);

		add_settings_field(
			$this->plugin_name.'_timer_portada',
			__( 'Tiempo Portada', 'alexandria-mail-builder' ),
			array( $this, 'tiempo_portada' ),
			$this->plugin_name . '-settings',
			'general_fields_setting_section',
			$this->plugin_name . '-option-group'              
		);

		add_settings_field(
			$this->plugin_name.'_descripcion_portada',
			__( 'Descripción Portada', 'alexandria-mail-builder' ),
			array( $this, 'descripcion_portada' ),
			$this->plugin_name . '-settings',
			'general_fields_setting_section',
			$this->plugin_name . '-option-group'              
		);

		add_settings_field(
			$this->plugin_name.'_email_primary_color',
			__( 'Color cabecera interior builder', 'alexandria-mail-builder' ),
			array( $this, 'color_barra_cabecera_interior' ),
			$this->plugin_name . '-styles',
			'style_fields_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_header_text',
			__( 'Texto cabecera builder', 'alexandria-mail-builder' ),
			array( $this, 'texto_barra_cabecera_interior' ),
			$this->plugin_name . '-styles',
			'style_fields_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_color_texto_barra_cabecera_interior',
			__( 'Color texto cabecera builder', 'alexandria-mail-builder' ),
			array( $this, 'color_texto_barra_cabecera_interior' ),
			$this->plugin_name . '-styles',
			'style_fields_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_button_text',
			__( 'Texto', 'alexandria-mail-builder' ),
			array( $this, 'button_text' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'       
		);

		add_settings_field(
			$this->plugin_name.'_button_bg_color',
			__( 'Color Fondo', 'alexandria-mail-builder' ),
			array( $this, 'button_bg_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'            
		);

		add_settings_field(
			$this->plugin_name.'_button_text_color',
			__( 'Color Texto', 'alexandria-mail-builder' ),
			array( $this, 'button_text_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'         
		);

		add_settings_field(
			$this->plugin_name.'_button_border_color',
			__( 'Color Borde', 'alexandria-mail-builder' ),
			array( $this, 'button_border_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'         
		);

		add_settings_field(
			$this->plugin_name.'_button_bg_hover_color',
			__( 'Color Fondo Hover', 'alexandria-mail-builder' ),
			array( $this, 'button_bg_hover_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'            
		);

		add_settings_field(
			$this->plugin_name.'_button_text_hover_color',
			__( 'Color Texto Hover', 'alexandria-mail-builder' ),
			array( $this, 'button_text_hover_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'         
		);

		add_settings_field(
			$this->plugin_name.'_button_border_hover_color',
			__( 'Color Borde Hover', 'alexandria-mail-builder' ),
			array( $this, 'button_border_hover_color' ),
			$this->plugin_name . '-styles',
			'button_style_fields_setting_section',
			$this->plugin_name . '-option-group'         
		);

		// Contact Form Fields
		add_settings_field(
			$this->plugin_name.'_contact_form_type',
			__( 'Tipo de Formulario', 'alexandria-mail-builder' ),
			array( $this, 'contact_form_type_setting' ),
			$this->plugin_name . '-contact-type',
			'contact_form_type_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_contact_form_id',
			__( 'Form Contact 7', 'alexandria-mail-builder' ),
			array( $this, 'contact_form_id_setting' ),
			$this->plugin_name . '-contact-form-7',
			'contact_form_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_sender_mail',
			__( 'Correo Electrónico Contacto', 'alexandria-mail-builder' ),
			array( $this, 'sender_mail_setting' ),
			$this->plugin_name . '-contact',
			'custom_contact_form_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_subject_mail',
			__( 'Email Subject', 'alexandria-mail-builder' ),
			array( $this, 'subject_mail_setting' ),
			$this->plugin_name . '-contact',
			'custom_contact_form_setting_section',
			$this->plugin_name . '-option-group'          
		);

		add_settings_field(
			$this->plugin_name.'_message_mail',
			__( 'Email Message template', 'alexandria-mail-builder' ),
			array( $this, 'message_mail_setting' ),
			$this->plugin_name . '-contact',
			'custom_contact_form_setting_section',
			$this->plugin_name . '-option-group'         
		);

	}

	public function print_general_section_info()
	{
		echo '<p>Opciones Generales</p>';
	}

	public function print_section_info()
	{
		_e('Estilos generales del Builder:', 'alexandria-mail-builder');
	}

	public function print_contact_form_info()
	{
		print 'Enter your settings below:';
	}

	public function print_contact_form_seven_info()
	{
		_e('Seleccionar el formulario:', 'alexandria-mail-builder');
	}

	public function register_settings() {

		register_setting(
			$this->plugin_name . '-option-group',
			$this->plugin_name .'-main-settings',
			array( $this, 'validate_options' )
		);

		register_setting(
			$this->plugin_name . '-styles-group',
			$this->plugin_name .'-main-settings',
			array( $this, 'validate_options' )
		);

		register_setting(
			$this->plugin_name . '-contact-form-type-group',
			$this->plugin_name .'-main-settings',
			array( $this, 'validate_options' )
		);

		register_setting(
			$this->plugin_name . '-contact-form-custom-group',
			$this->plugin_name .'-main-settings',
			array( $this, 'validate_options' )
		);

		register_setting(
			$this->plugin_name . '-contact-form-group',
			$this->plugin_name .'-main-settings',
			array( $this, 'validate_options' )
		);

	}

	private function sanitizer( $type, $data ) {

		if ( empty( $type ) ) { return; }
		if ( empty( $data ) ) { return; }

		$return 	= '';
		$sanitizer 	= new Alexandria_Mail_Sanitize();

		$sanitizer->set_data( $data );
		$sanitizer->set_type( $type );

		$return = $sanitizer->clean();

		unset( $sanitizer );

		return $return;

	} // sanitizer()


	/**
	* Validates saved options
	*
	* @since 		1.0.0
	* @param 		array 		$input 			array of submitted plugin options
	* @return 		array 						array of validated plugin options
	*/
	public function validate_options( $input ) {

		if( !empty( $input[$this->plugin_name .'_sender_mail'] )) {

			if( !is_email( $input[$this->plugin_name .'_sender_mail'] )) {

				$type = 'error';
				$message = __( 'El formato del correo electrónico es incorrecto.', 'alexandria-conversation-builder' );

				add_settings_error(
					'email-error-type',
					esc_attr( 'settings_updated' ),
					$message,
					$type
				);

				return false; 
			}

		}

		if( !empty( $input[$this->plugin_name .'_contact_type'] )) {
			update_option( $this->plugin_name .'_contact_type', $input[$this->plugin_name .'_contact_type'] );	
		}

		if(function_exists('icl_object_id')) {

			$languages = apply_filters( 'wpml_active_languages', NULL, 'orderby=id&order=desc' );

			if ( !empty( $languages ) ) {

				foreach( $languages as $lang ) { 
					if( !empty( $input[$this->plugin_name .'_contact_form_id_email_'.esc_attr( $lang['language_code'] )] )) {
						update_option( $this->plugin_name .'_contact_form_id_email_'.esc_attr( $lang['language_code'] ), $input[$this->plugin_name .'_contact_form_id_email_'.esc_attr( $lang['language_code'] )] ); 
					}
				}
			}

		} else {

			if( !empty( $input[$this->plugin_name .'_contact_form_id'] )) {
				update_option( $this->plugin_name .'_contact_form_id', $input[$this->plugin_name .'_contact_form_id'] ); 
			}
		}

		if( !empty( $input[$this->plugin_name .'_sender_email'] )) {
			update_option( $this->plugin_name .'_sender_email', $input[$this->plugin_name .'_sender_email'] );
		}

		if( !empty( $input[$this->plugin_name .'_subject_email'] )) {
			update_option( $this->plugin_name .'_subject_email', $input[$this->plugin_name .'_subject_email'] );
		}
		
		if( !empty( $input[$this->plugin_name .'_message_email'] )) {
			update_option( $this->plugin_name .'_message_email', $input[$this->plugin_name .'_message_email'] );
		}

		if( !empty( $input[$this->plugin_name .'_header_background_image_id'] )) {
			update_option( $this->plugin_name .'_header_background_image_id', $input[$this->plugin_name .'_header_background_image_id'] );
		}

		if( !empty( $input[$this->plugin_name .'_header_bg_color'] )) {
			update_option( $this->plugin_name .'_header_bg_color', $input[$this->plugin_name .'_header_bg_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_header_text'] )) {
			update_option( $this->plugin_name .'_header_text', $input[$this->plugin_name .'_header_text'] );
		}

		if( !empty( $input[$this->plugin_name .'_header_text_color'] )) {
			update_option( $this->plugin_name .'_header_text_color', $input[$this->plugin_name .'_header_text_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_titulo_portada'] )) {
			update_option( $this->plugin_name .'_titulo_portada', $input[$this->plugin_name .'_titulo_portada'] );
		}

		if( !empty( $input[$this->plugin_name .'_subtitulo_portada'] )) {
			update_option( $this->plugin_name .'_subtitulo_portada', $input[$this->plugin_name .'_subtitulo_portada'] );
		}

		if( !empty( $input[$this->plugin_name .'_descripcion_portada'] )) {
			update_option( $this->plugin_name .'_descripcion_portada', $input[$this->plugin_name .'_descripcion_portada'] );
		}

		if( !empty( $input[$this->plugin_name.'_tiempo_portada'] )) {
			update_option( $this->plugin_name.'_tiempo_portada', $input[$this->plugin_name.'_tiempo_portada'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_text'] )) {
			update_option( $this->plugin_name .'_button_text', $input[$this->plugin_name .'_button_text'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_bg_color'] )) {
			update_option( $this->plugin_name .'_button_bg_color', $input[$this->plugin_name .'_button_bg_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_text_color'] )) {
			update_option( $this->plugin_name .'_button_text_color', $input[$this->plugin_name .'_button_text_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_border_color'] )) {
			update_option( $this->plugin_name .'_button_border_color', $input[$this->plugin_name .'_button_border_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_bg_hover_color'] )) {
			update_option( $this->plugin_name .'_button_bg_hover_color', $input[$this->plugin_name .'_button_bg_hover_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_text_hover_color'] )) {
			update_option( $this->plugin_name .'_button_text_hover_color', $input[$this->plugin_name .'_button_text_hover_color'] );
		}

		if( !empty( $input[$this->plugin_name .'_button_border_hover_color'] )) {
			update_option( $this->plugin_name .'_button_border_hover_color', $input[$this->plugin_name .'_button_border_hover_color'] );
		}

		if( !empty( $input[$this->plugin_name.'_color_barra_cabecera_interior'] )) {
			update_option( $this->plugin_name.'_color_barra_cabecera_interior', $input[$this->plugin_name.'_color_barra_cabecera_interior'] );
		}

		if( !empty( $input[$this->plugin_name.'_texto_barra_cabecera_interior'] )) {
			update_option( $this->plugin_name.'_texto_barra_cabecera_interior', $input[$this->plugin_name.'_texto_barra_cabecera_interior'] );
		}

		if( !empty( $input[$this->plugin_name .'_color_texto_barra_cabecera_interior'] )) {
			update_option( $this->plugin_name .'_color_texto_barra_cabecera_interior', $input[$this->plugin_name .'_color_texto_barra_cabecera_interior'] );
		}

		return $input;

	} // validate_options()

}