<?php

/**
* Principal Controller
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Conversation_Builder
* @subpackage 	Alexandria_Conversation_Builder/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class MainController {

	static function intiBuilder() {

		$data = [
			'interlocutors' => [],
			'situations_categories' => [],
			'tonos' => []
		];

		$args = array(  
			'post_type' => 'interlocutors',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$data['interlocutors'] = get_posts($args);

		$cat_args = array(
			'post_type' 	=> 'situations',
			'post_status' 	=> 'publish',
			'taxonomy'     	=> 'situations-categories',
			'orderby'       => 'id',
			'order'         => 'ASC',
			'field'        	=> 'slug',
			'suppress_filters' => 0,
			'include_children' => false
		);

		$categories = get_categories($cat_args);

		foreach ( $categories as $key => $category ) {

			$data['situations_categories'][$key]['category'] = $category;

			$situations_args = [
				'post_type' => 'situations',
				'orderby'   => 'title',
				'order'     => 'ASC',
				'suppress_filters' => 0,
				'tax_query' => [
					[
						'taxonomy' => 'situations-categories',
						'terms' => $category->term_id,
						'include_children' => false
					],
				],

			];

			$situations = get_posts($situations_args);

			foreach ( $situations as $index => $situation ) {

				$data['situations_categories'][$key]['situations'][$index] = $situation;

			}

		}

		$args = array(  
			'post_type' => 'tonos',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'order', 
			'order' => 'ASC'
		);

		$data['tonos'] = get_posts($args);

		echo '|ALEXANDRIACONVERSATIONBUILDER|';

		do_action('alexandria_show_main_template', 'main_template', $data);

	} // end index


	static function getConversationMetadata() {

		$interlocutor_id = $_POST['interlocutor'];
		$situation_id = $_POST['situation'];
		$tono_id = $_POST['tono'];

		$data = [];

		$args = array(  
			'post_type' => 'conversations',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$conversations = get_posts($args);

		foreach ($conversations as $key => $conversation) {

			$metadata_array = array(
				
				'interlocutor' => get_post(get_post_meta( $conversation->ID, '_interlocutor', true )),
				'tono' => get_post(get_post_meta( $conversation->ID, '_tono', true )),
				'situation' => get_post(get_post_meta( $conversation->ID, '_situation', true )),

				'objectives' => get_post(get_post_meta( $conversation->ID, '_objective', true )),
				'soliloquios' => [],
				'conclusions' => [],
				'decisions' => [],
				'expect_results' => [],

				'strong_questions' => [],
				'relevance' => get_post(get_post_meta( $conversation->ID, '_relevance', true )),
				'arguments' => [],
				'viable_minimal' => [],
				'comments' => [],
				'builder_examples' => []
			);

			$soliloquios = get_post_meta( $conversation->ID, '_soliloquios', true );
			$conclusions = get_post_meta( $conversation->ID, '_conclusions', true );
			$decisions = get_post_meta( $conversation->ID, '_decisions', true );
			$expect_results = get_post_meta( $conversation->ID, '_expect_results', true );

			$strong_questions = get_post_meta( $conversation->ID, '_strong_questions', true );
			$arguments = get_post_meta( $conversation->ID, '_arguments', true );
			$viable_minimal = get_post_meta( $conversation->ID, '_viable_minimal', true );
			$comments = get_post_meta( $conversation->ID, '_conversation_comments', true );

			$examples = get_post_meta( $conversation->ID, '_examples', true );
			
			
			foreach ($soliloquios as $index => $value) {
				$metadata_array['soliloquios'][$index] = get_post($value);
			}

			foreach ($conclusions as $index => $value) {
				$metadata_array['conclusions'][$index] = get_post($value);
			}

			foreach ($decisions as $index => $value) {
				$metadata_array['decisions'][$index] = get_post($value);
			}

			foreach ($expect_results as $index => $value) {
				$metadata_array['expect_results'][$index] = get_post($value);
			}

			foreach ($arguments as $index => $value) {
				$metadata_array['arguments'][$index] = get_post($value);
			}

			foreach ($viable_minimal as $index => $value) {
				$metadata_array['viable_minimal'][$index] = get_post($value);
			}

			foreach ($comments as $index => $value) {
				$metadata_array['comments'][$index] = get_post($value);
			}

			foreach ($examples as $index => $value) {
				$post = get_post($value);
				$metadata_array['examples'][$index] = get_post($value);
				$metadata_array['examples'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			foreach ($strong_questions as $index => $value) {

				$post = get_post($value);
				$terms = get_the_terms($post->ID, 'strong_questions-categories');
				$term = array_pop($terms);

				$metadata_array['strong_questions'][$index] = $post;
				$metadata_array['strong_questions'][$index]->category = $term;
				$metadata_array['strong_questions'][$index]->video_type = get_post_meta($post->ID,'video_type', true);
				$metadata_array['strong_questions'][$index]->video_id = get_post_meta($post->ID,'video_id', true);
				$metadata_array['strong_questions'][$index]->video_id = get_post_meta($post->ID,'video_url', true);
			}

			if($metadata_array['interlocutor']->ID == intval($interlocutor_id) && $metadata_array['situation']->ID == intval($situation_id) && $metadata_array['tono']->ID == intval($tono_id)) 
			{
				$data['conversation'] = $conversation;
				$data['metadata'] = $metadata_array;
			}	

		}

		echo json_encode($data);
	}

}