<?php

/**
 * Conversations CPT Metaboxes
 *
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Conversation_Builder
 * @subpackage Alexandria_Conversation_Builder/admin/models
 */

/*
* Creating a function to create our CPT
*/

class Alexandria_Conversation_Conversations_Metaboxes {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


	function interlocutor_fields() {

		global $post;

		$selected_interlocutor = get_post_meta( $post->ID, '_interlocutor', true );

		$all_interlocutors = get_posts( array(
			'post_type' => 'interlocutors',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));

		?>

		<input type="hidden" name="interlocutor_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<div class="custom-metabox">

			<div class="metabox-right">

				<table class="form-table">

					<tr valign="top">

						<th scope="row">
							<label for="interlocutor">
								<?php _e('Interlocutor', $this->plugin_name); ?>
							</label>
						</th>

						<td>

							<select id="select_interlocutor" name="interlocutor">

								<option value="0">
									<?php _e('Seleccionar', '').' '._e(' Interlocutor', ''); ?>
								</option>

								<?php foreach ( $all_interlocutors as $interlocutor ) : ?>
									<option value="<?php echo $interlocutor->ID; ?>" <?php echo $interlocutor->ID == $selected_interlocutor ? 'selected' : ''; ?>>
										<?php echo $interlocutor->post_title; ?>		
									</option>
								<?php endforeach; ?>

							</select>

						</td>

					</tr>

				</table>
				
			</div>

<!-- 			<div class="metabox-left">

				<label for="interlocutor">
					<?php _e('Añadir Nuevo Interlocutor', $this->plugin_name); ?>
				</label>
				<input type="text" name="new_interlocutor_title" placeholder="Nuevo Interlocutor" />
				<a href="#">+ añadir nuevo interlocutor</a>

				<p class="description">Puede añadir un nuevo interlocutor desde aquí y luego seleccionarlo en la lista desplegable de la izquierda.</p>

			</div> -->

		</div>



		<?php 
	}

	function tono_fields() {

		global $post;

		$selected_tono = get_post_meta( $post->ID, '_tono', true );

		$all_tonos = get_posts( array(
			'post_type' => 'tonos',
			'numberposts' => -1,
			'orderby' => 'title',
			'order' => 'ASC'
		));

		?>

		<input type="hidden" name="tono_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="tono"><?php _e('Tono', ''); ?></label>
				</th>
				<td>
					<select id="select_tono" name="tono">

						<option value="0">Seleccionar Tono</option>

						<?php foreach ( $all_tonos as $tono ) : ?>
							<option value="<?php echo $tono->ID; ?>" <?php echo $tono->ID == $selected_tono ? 'selected' : ''; ?>>
								<?php echo $tono->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>
				</td>
			</tr>

		</table>

		<?php 
	}

	function situation_fields() {

		global $post;

		$selected_situation = get_post_meta( $post->ID, '_situation', true );

		$all_situations = get_posts( array(
			'post_type' => 'situations',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="situation_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<th scope="row">
					<label for="situation"><?php _e('Situación', ''); ?></label>
				</th>

				<td>
					<select id="select_situation" name="situation">

						<option value="0"><?php _e('Seleccionar Situación', $this->plugin_name); ?></option>

						<?php foreach ( $all_situations as $situation ) : ?>
							<option value="<?php echo $situation->ID; ?>" <?php echo $situation->ID == $selected_situation ? 'selected' : ''; ?>>
								<?php echo $situation->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function objectives_fields() {

		global $post;

		$selected_objective = get_post_meta( $post->ID, '_objective', true );

		$all_objectives = get_posts( array(
			'post_type' => 'objectives',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); 

		?>

		<input type="hidden" name="objective_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<th scope="row">
					<label for="objective"><?php _e('Objetivo', ''); ?></label>
				</th>

				<td>
					<select id="select_objective" name="objective">

						<option value="0">
							<?php _e('Seleccionar', $this->plugin_name).' '._e(' Objetivo', $this->plugin_name); ?>
						</option>

						<?php foreach ( $all_objectives as $objective ) : ?>
							<option value="<?php echo $objective->ID; ?>" <?php echo $objective->ID == $selected_objective ? 'selected' : ''; ?>>
								<?php echo $objective->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}


	function soliloquios_fields() {

		global $post;

		$selected_soliloquios = get_post_meta( $post->ID, '_soliloquios', true );

		$all_soliloquios = get_posts( array(
			'post_type' => 'soliloquios',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="soliloquios_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_soliloquios" name="soliloquios[]">

						<?php foreach ( $all_soliloquios as $soliloquio ) : ?>

							<option value="<?php echo $soliloquio->ID; ?>"

								<?php 

								if(is_array($selected_soliloquios)) {
									echo (in_array($soliloquio->ID, $selected_soliloquios) ? 'selected' : '');
								} else {
									echo $soliloquio->ID == $selected_soliloquios ? 'selected' : '';
								}

								?>

								>

								<?php echo $soliloquio->post_title; ?>	
							</option>

						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}


	function conclusions_fields() {

		global $post;

		$selected_conclusions = get_post_meta( $post->ID, '_conclusions', true );

		$all_conclusions = get_posts( array(
			'post_type' => 'conclusions',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="conclusions_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_conclusions" name="conclusions[]">

						<?php foreach ( $all_conclusions as $conclusions ) : ?>
							<option value="<?php echo $conclusions->ID; ?>"	
								<?php 

								if(is_array($selected_conclusions)) {
									echo (in_array($conclusions->ID, $selected_conclusions) ? 'selected' : '');
								} else {
									echo $conclusions->ID == $selected_conclusions ? 'selected' : '';
								}

								?>

								>

								<?php echo $conclusions->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function decisions_fields() {

		global $post;

		$selected_decisions = get_post_meta( $post->ID, '_decisions', true );

		$all_decisions = get_posts( array(
			'post_type' => 'decisions',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="decisions_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_decisions" name="decisions[]">

						<?php foreach ( $all_decisions as $decisions ) : ?>
							<option value="<?php echo $decisions->ID; ?>" 

								<?php 

								if(is_array($selected_decisions)) {
									echo (in_array($decisions->ID, $selected_decisions) ? 'selected' : '');
								} else {
									echo $decisions->ID == $selected_decisions ? 'selected' : '';
								}

								?>

								>

								<?php echo $decisions->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function expect_results_fields() {

		global $post;

		$selected_expect_results = get_post_meta( $post->ID, '_expect_results', true );

		$all_expect_results = get_posts( array(
			'post_type' => 'expect_results',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="expect_results_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_expect_results" name="expect_results[]">

						<?php foreach ( $all_expect_results as $expect_result ) : ?>
							<option value="<?php echo $expect_result->ID; ?>" 
								<?php 

								if(is_array($selected_expect_results)) {
									echo (in_array($expect_result->ID, $selected_expect_results) ? 'selected' : '');
								} else {
									echo $expect_result->ID == $selected_expect_results ? 'selected' : '';
								}

								?>

								>
								<?php echo $expect_result->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function strong_questions_fields() {

		global $post;

		$selected_strong_questions = get_post_meta( $post->ID, '_strong_questions', true );

		$all_strong_questions = get_posts( array(
			'post_type' => 'strong_questions',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="strong_questions_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="strong_questions" name="strong_questions[]">

						<?php foreach ( $all_strong_questions as $pregunta_potente ) : ?>
							<option value="<?php echo $pregunta_potente->ID; ?>" 
								<?php 

								if(is_array($selected_strong_questions)) {
									echo (in_array($pregunta_potente->ID, $selected_strong_questions) ? 'selected' : '');
								} else {
									echo $pregunta_potente->ID == $selected_strong_questions ? 'selected' : '';
								}

								?>

								>
								<?php echo $pregunta_potente->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function relevance_fields() {

		global $post;

		$selected_relevance = get_post_meta( $post->ID, '_relevance', true );

		$all_relevances = get_posts( array(
			'post_type' => 'relevances',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="relevance_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<th scope="row">
					<label for="relevance">
						<?php _e('Relevancia', $this->plugin_name); ?>
					</label>
				</th>

				<td>
					<select id="select_relevance" name="relevance">

						<option value="0">
							<?php _e('Seleccionar', '').' '._e(' Relevancia', ''); ?>
						</option>

						<?php foreach ( $all_relevances as $relevance ) : ?>
							<option value="<?php echo $relevance->ID; ?>" <?php echo $relevance->ID == $selected_relevance ? 'selected' : ''; ?>>
								<?php echo $relevance->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function argumentos_fields() {

		global $post;

		$selected_arguments = get_post_meta( $post->ID, '_arguments', true );

		$all_argumentos = get_posts( array(
			'post_type' => 'arguments',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); 

		?>

		<input type="hidden" name="arguments_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_arguments" name="arguments[]">

						<?php foreach ( $all_argumentos as $argument ) : ?>
							<option value="<?php echo $argument->ID; ?>"
								<?php 

								if(is_array($selected_arguments)) {
									echo (in_array($argument->ID, $selected_arguments) ? 'selected' : '');
								} else {
									echo $argument->ID == $selected_arguments ? 'selected' : '';
								}

								?>

								>
								<?php echo $argument->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function viable_minimal_fields() {

		global $post;

		$selected_viable_minimal = get_post_meta( $post->ID, '_viable_minimal', true );

		$all_viable_minimal = get_posts( array(
			'post_type' => 'viable_minimal',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));

		?>

		<input type="hidden" name="viable_minimal_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_viable_minimal" name="viable_minimal[]">

						<?php foreach ( $all_viable_minimal as $viable_minimal ) : ?>
							<option value="<?php echo $viable_minimal->ID; ?>"
								<?php 

								if(is_array($selected_viable_minimal)) {
									echo (in_array($viable_minimal->ID, $selected_viable_minimal) ? 'selected' : '');
								} else {
									echo $viable_minimal->ID == $selected_viable_minimal ? 'selected' : '';
								}

								?>

								>
								<?php echo $viable_minimal->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function comentarios_fields() {

		global $post;

		$selected_conversation_comments = get_post_meta( $post->ID, '_conversation_comments', true );	

		$all_conversation_comments = get_posts( array(
			'post_type' => 'alexandria_comments',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));


		?>
		
		<input type="hidden" name="conversation_comments_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />
		
		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					
					<select multiple id="select_comments" name="conversation_comments[]">

						<?php foreach ( $all_conversation_comments as $comment ) : ?>

							<option title="<?php echo $comment->post_title; ?>" value="<?php echo $comment->ID; ?>"
								<?php 

								if(is_array($selected_conversation_comments)) {
									echo (in_array($comment->ID, $selected_conversation_comments) ? 'selected' : '');
								} else {
									echo $comment->ID == $selected_conversation_comments ? 'selected' : '';
								}

								?>

								>
								<?php echo substr($comment->post_title, 0, 100); ?>...		
							</option>

						<?php endforeach; ?>

					</select>

				</td>

			</tr> 

		</table>

		<?php
	}

	function examples_fields() {

		global $post;

		$selected_examples = get_post_meta( $post->ID, '_examples', true );

		$all_examples = get_posts( array(
			'post_type' => 'builder_examples',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="examples_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ )); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_examples" name="examples[]">
						<?php foreach ( $all_examples as $example ) : ?>
							<option value="<?php echo $example->ID; ?>" 

								<?php 

								if(is_array($selected_examples)) {
									echo (in_array($example->ID, $selected_examples) ? 'selected' : '');
								} else {
									echo $example->ID == $selected_examples ? 'selected' : '';
								}

								?>

								>
								<?php echo $example->post_title; ?>		
							</option>
						<?php endforeach; ?>
					</select>

				</td>

			</tr>

		</table>

		<?php 
	}
	

	function alexandria_conversation_save_custom_fields( $post_id ) {

    	// only run this for conversations
		if ( 'conversations' != get_post_type( $post_id ) )
			return $post_id;        

    	// verify nonces
		if ( empty( $_POST['interlocutor_nonce'] ) || !wp_verify_nonce( $_POST['interlocutor_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['situation_nonce'] ) || !wp_verify_nonce( $_POST['situation_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['tono_nonce'] ) || !wp_verify_nonce( $_POST['tono_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['objective_nonce'] ) || !wp_verify_nonce( $_POST['objective_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['soliloquios_nonce'] ) || !wp_verify_nonce( $_POST['soliloquios_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['conclusions_nonce'] ) || !wp_verify_nonce( $_POST['conclusions_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['decisions_nonce'] ) || !wp_verify_nonce( $_POST['decisions_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['expect_results_nonce'] ) || !wp_verify_nonce( $_POST['expect_results_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['strong_questions_nonce'] ) || !wp_verify_nonce( $_POST['strong_questions_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['relevance_nonce'] ) || !wp_verify_nonce( $_POST['relevance_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['arguments_nonce'] ) || !wp_verify_nonce( $_POST['arguments_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['viable_minimal_nonce'] ) || !wp_verify_nonce( $_POST['viable_minimal_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['conversation_comments_nonce'] ) || !wp_verify_nonce( $_POST['conversation_comments_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['examples_nonce'] ) || !wp_verify_nonce( $_POST['examples_nonce'], basename( __FILE__ ) ) )
			return $post_id;

    				// check autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

    				// check permissions
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;


    	// save
		update_post_meta($post_id, '_interlocutor', intval($_POST['interlocutor']));
		update_post_meta($post_id, '_situation', intval($_POST['situation']));
		update_post_meta($post_id, '_tono', intval($_POST['tono']));
		update_post_meta($post_id, '_objective', intval($_POST['objective']));

		update_post_meta($post_id, '_relevance', intval($_POST['relevance']));


		// Multiples values
		if(isset($_POST['conclusions'])) {
			update_post_meta($post_id, '_conclusions', array_map('intval', $_POST['conclusions']));
		} else {
			update_post_meta($post_id, '_conclusions', array());
		}

		if(isset($_POST['decisions'])) {
			update_post_meta($post_id, '_decisions', array_map('intval', $_POST['decisions']));
		} else {
			update_post_meta($post_id, '_decisions', array());
		}

		if(isset($_POST['expect_results'])) {
			update_post_meta($post_id, '_expect_results', array_map('intval', $_POST['expect_results']));
		} else {
			update_post_meta($post_id, '_expect_results', array());
		}

		if(isset($_POST['examples'])) {
			update_post_meta($post_id, '_examples', array_map('intval', $_POST['examples']));
		} else {
			update_post_meta($post_id, '_examples', array());
		}

		if(isset($_POST['conclusions'])) {
			update_post_meta($post_id, '_conclusions', array_map('intval', $_POST['conclusions']));
		} else {
			update_post_meta($post_id, '_conclusions', array());
		}

		if(isset($_POST['arguments'])) {
			update_post_meta($post_id, '_arguments', array_map('intval', $_POST['arguments']));
		} else {
			update_post_meta($post_id, '_arguments', array());
		}

		if(isset($_POST['viable_minimal'])) {
			update_post_meta($post_id, '_viable_minimal', array_map('intval', $_POST['viable_minimal']));
		} else {
			update_post_meta($post_id, '_viable_minimal', array());
		}

		if(isset($_POST['conversation_comments'])) {
			update_post_meta($post_id, '_conversation_comments', array_map('intval', $_POST['conversation_comments']));
		} else {
			update_post_meta($post_id, '_conversation_comments', array());
		}

		if(isset($_POST['soliloquios'])) {
			update_post_meta($post_id, '_soliloquios', array_map('intval', $_POST['soliloquios']));
		} else {
			update_post_meta($post_id, '_soliloquios', array());
		}

		if(isset($_POST['strong_questions'])) {
			update_post_meta($post_id, '_strong_questions', array_map('intval', $_POST['strong_questions']));
		} else {
			update_post_meta($post_id, '_strong_questions', array());
		}

	}

	function conversations_column_register_sortable($columns){
		$columns['interlocutor'] = 'interlocutor';
		$columns['situation'] = 'situation';
		$columns['tono'] = 'tono';
		$columns['objective'] = 'objective';
		$columns['soliloquios'] = 'soliloquios';
		$columns['conclusions'] = 'conclusions';
		$columns['decisions'] = 'decisions';
		$columns['expect_results'] = 'expect_results';
		$columns['strong_questions'] = 'strong_questions';
		$columns['relevances'] = 'relevances';
		$columns['arguments'] = 'arguments';
		$columns['viable_minimal'] = 'viable_minimal';
		$columns['conversation_comments'] = 'conversation_comments';
		$columns['examples'] = 'examples';
		
		return $columns;
	}

	// Add the custom columns to the book post type:
	function set_custom_edit_conversations_columns($columns) {
		unset( $columns['title'] );
		unset( $columns['date'] );
		$columns['interlocutor'] = __( 'Interlocutor', $this->plugin_name );
		$columns['situation'] = __( 'Situación', $this->plugin_name );
		$columns['tono'] = __( 'Tono', $this->plugin_name );
		$columns['objective'] = __( 'Objetivo', $this->plugin_name );
		$columns['soliloquios'] = __( 'Soliloquios', $this->plugin_name );
		$columns['conclusions'] = __( 'Conclusiones', $this->plugin_name );
		$columns['decisions'] = __( 'Decisiones', $this->plugin_name );
		$columns['expect_results'] = __( 'Resultados Esperados', $this->plugin_name );
		$columns['strong_questions'] = __( 'Preguntas Potentes', $this->plugin_name );
		$columns['relevances'] = __( 'Relevancia', $this->plugin_name );
		$columns['arguments'] = __( 'Argumentos', $this->plugin_name );
		$columns['viable_minimal'] = __( 'Mínimo Viable', $this->plugin_name );
		$columns['conversation_comments'] = __( 'Comentarios', $this->plugin_name );
		$columns['examples'] = __( 'Ejemplos', $this->plugin_name );

		return $columns;
	}

	// Add the data to the custom columns for the book post type:
	function custom_conversations_column( $column, $post_id ) {

		switch ( $column ) {

			case 'interlocutor' :
			$interlocutor = get_post_meta( $post_id, '_interlocutor', true );
			if($interlocutor != null){
				echo get_the_title($interlocutor);
			} else {
				_e('Sin Interlocutor', $this->plugin_name);
			}
			break;
			case 'situation' :
			$situation = get_post_meta( $post_id, '_situation', true );
			if($situation != null){
				echo get_the_title($situation );
			} else {
				_e('Sin Situación', $this->plugin_name);
			}
			break;
			case 'tono' :
			$tono = get_post_meta( $post_id, '_tono', true );
			if($tono != null){
				echo get_the_title($tono);
			} else {
				_e('Sin Tono', $this->plugin_name);
			}
			break;
			case 'objective' :
			$objective = get_post_meta( $post_id, '_objective', true );
			if($objective != null){
				echo get_the_title($objective);
			} else {
				_e('Sin Objetivos', $this->plugin_name);
			}
			break;
			case 'soliloquios' :
			$soliloquios = get_post_meta( $post_id, '_soliloquios', true );
			if($soliloquios != null){
				foreach ($soliloquios as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Soliloquios', $this->plugin_name);
			}
			break;
			case 'conclusions' :
			$conclusions = get_post_meta( $post_id, '_conclusions', true );
			if($conclusions != null){
				foreach ($conclusions as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Conclusiones', $this->plugin_name);
			}
			break;
			case 'decisions' :
			$decisions = get_post_meta( $post_id, '_decisions', true );
			if($decisions != null){
				foreach ($decisions as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Decisiones', $this->plugin_name);
			}
			break;
			case 'expect_results' :
			$expect_results = get_post_meta( $post_id, '_expect_results', true );
			if($expect_results != null){
				foreach ($expect_results as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Resultados Esperados', $this->plugin_name);
			}
			break;
			case 'examples' :
			$examples = get_post_meta( $post_id, '_examples', true );
			if($examples != null){
				foreach ($examples as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Ejemplos', $this->plugin_name);
			}
			break;
			case 'relevances' :
			$relevance = get_post_meta( $post_id, '_relevance', true );
			if($relevance != null){
				echo get_the_title($relevance);	
			} else {
				_e('Sin Relevancia', $this->plugin_name);
			}
			break;
			case 'arguments' :
			$arguments = get_post_meta( $post_id, '_arguments', true );
			if($arguments != null){
				foreach ($arguments as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Argumentos', $this->plugin_name);
			}
			break;
			case 'viable_minimal' :
			$viable_minimal = get_post_meta( $post_id, '_viable_minimal', true );
			if($viable_minimal != null){
				foreach ($viable_minimal as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Mínimo Viable', $this->plugin_name);
			}
			break;
			case 'conversation_comments' :
			$conversation_comments = get_post_meta( $post_id, '_conversation_comments', true );
			if($conversation_comments != null){
				foreach ($conversation_comments as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Comentarios', $this->plugin_name);
			}
			break;
			case 'strong_questions' :
			$strong_questions = get_post_meta( $post_id, '_strong_questions', true );
			if($strong_questions != null){
				foreach ($strong_questions as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Preguntas Potentes', $this->plugin_name);
			}
			break;

		}
	}

	/**
	 * Display a custom taxonomy dropdown in admin
	 * @author Mike Hemberger
	 * @link http://thestizmedia.com/custom-post-type-filter-admin-custom-taxonomy/
	 */
	

	function tsm_filter_post_type_by_taxonomy() {
		$type = 'post';
		if (isset($_GET['post_type'])) {
			$type = $_GET['post_type'];
		}

		if ('conversations' == $type){

			$all_interlocutors = get_posts( array(
				'post_type' => 'interlocutors',
				'numberposts' => -1,
				'orderby' => 'post_title',
				'order' => 'ASC'
			));

			?>
			<select name="interlocutor_id">

				<option value=""><?php _e('Filtrar por ', 'alexandria-conversation-builder'); ?></option>

				<?php

				$current_v = isset($_GET['interlocutor_id']) ? $_GET['interlocutor_id'] : '';

				foreach ($all_interlocutors as $value) {
					printf
					(
						'<option value="%s"%s>%s</option>',
						$value->ID,
						$value->ID == $current_v? ' selected="selected"':'',
						$value->post_title
					);
				}
				?>
			</select>
			<?php
		}
	}

	/**
	 * Filter posts by custom metabox field in admin
	 * @author  Mike Hemberger
	 * @link http://thestizmedia.com/custom-post-type-filter-admin-custom-taxonomy/
	 */
	function tsm_convert_id_to_term_in_query($query) {

		global $pagenow;

		$type = 'post';

		if (isset($_GET['post_type'])) {
			$type = $_GET['post_type'];
		}

		if ( 'POST_TYPE' == $type && is_admin() && $pagenow=='edit.php' && isset($_GET['interlocutor_id']) && $_GET['interlocutor_id'] != '') {
			$query->query_vars['meta_key'] = '_interlocutor';
			$query->query_vars['meta_value'] = $_GET['interlocutor_id'];
		}
	}

}