<?php 

/**
 * Tonos CPT Metaboxes
 *
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Conversation_Builder
 * @subpackage Alexandria_Conversation_Builder/admin/models
 */

/*
* Creating a function to create our CPT
*/

class Alexandria_Conversation_Tonos_Metaboxes {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	function alexandria_tonos_colors_meta_box( $post ){

		$custom = get_post_custom( $post->ID );
		$background_color = (isset($custom["background_color"][0])) ? $custom["background_color"][0] : '';
		$text_color = (isset($custom["text_color"][0])) ? $custom["text_color"][0] : '';
		$border_color = (isset($custom["border_color"][0])) ? $custom["border_color"][0] : '';
		$order = (isset($custom["order"][0])) ? $custom["order"][0] : '0';

		wp_nonce_field( 'alexandria_tonos_colors_meta_box', 'alexandria_tonos_colors_meta_box_nonce' );

		?>

		<style type="text/css">
			.hidden{ display: none; }
		</style>

		<div class="pagebox">
			<h4><?php esc_attr_e('Color Fondo', 'mytheme' ); ?></h4>
			<input class="color-field" type="text" name="background_color" value="<?php esc_attr_e(@$background_color); ?>"  data-default-color="#444" />

			<h4><?php esc_attr_e('Color Texto', 'mytheme' ); ?></h4>
			<input class="color-field" type="text" name="text_color" value="<?php esc_attr_e(@$text_color); ?>"  data-default-color="#444" />


			<h4><?php esc_attr_e('Color Bordes', 'mytheme' ); ?></h4>
			<input class="color-field" type="text" name="border_color" value="<?php esc_attr_e(@$border_color); ?>"  data-default-color="#444" />


			<input type="hidden" name="order" value="<?php esc_attr_e(@$order); ?>" />
		</div>

		<?php
	}

	function alexandria_tonos_save_meta_boxes( $post_id ){


		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		
		if( !current_user_can( 'edit_pages' ) ) {
			return;
		}

		if ( !isset( $_POST['background_color'] ) || !wp_verify_nonce( $_POST['alexandria_tonos_colors_meta_box_nonce'], 'alexandria_tonos_colors_meta_box' ) ) {
			return;
		}

		if ( !isset( $_POST['text_color'] ) || !wp_verify_nonce( $_POST['alexandria_tonos_colors_meta_box_nonce'], 'alexandria_tonos_colors_meta_box' ) ) {
			return;
		}

		if ( !isset( $_POST['border_color'] ) || !wp_verify_nonce( $_POST['alexandria_tonos_colors_meta_box_nonce'], 'alexandria_tonos_colors_meta_box' ) ) {
			return;
		}

		$background_color = (isset($_POST["background_color"]) && $_POST["background_color"]!='') ? $_POST["background_color"] : '';
		$text_color = (isset($_POST["text_color"]) && $_POST["text_color"]!='') ? $_POST["text_color"] : '';
		$border_color = (isset($_POST["border_color"]) && $_POST["border_color"]!='') ? $_POST["border_color"] : '';

		update_post_meta($post_id, "background_color", $background_color);
		update_post_meta($post_id, "text_color", $text_color);
		update_post_meta($post_id, "border_color", $border_color);

		$order = $_POST["order"];

		if($order == 0) {

			$count_tonos = wp_count_posts('tonos')->publish;

			update_post_meta($post_id, "order", $count_tonos);

		} else {
			update_post_meta($post_id, "order", $order);
		}

	}


	function reorder_tonos_on_delete( $post_id ) {

		if( 'tonos' != get_post_type( $post_id )){
			return false;
		}

		$tonos = get_posts( array(
			'post_type' => 'tonos',
			'numberposts' => -1,
			'orderby' => 'order',
			'order' => 'ASC',
			'post__not_in' => array( $post_id )
		));

		foreach ($tonos as $key => $tono) {
			update_post_meta($tono->ID, "order", $key + 1);
		}

	}

	function reorder_tonos_on_send_trash( $post_id ) {

		if( 'tonos' != get_post_type( $post_id )){
			return false;
		}

		$tonos = get_posts( array(
			'post_type' => 'tonos',
			'numberposts' => -1,
			'orderby' => 'order',
			'order' => 'ASC',
			'post__not_in' => array( $post_id )
		));

		foreach ($tonos as $key => $tono) {
			update_post_meta($tono->ID, "order", $key + 1);
		}

	}
	

	// Add the custom columns to the tonos post type:
	function set_custom_edit_tonos_columns($columns) {
		unset( $columns['date'] );
		$columns['background_color'] = __( 'Color', 'alexandria-conversation-builder' );
		$columns['order'] = __( 'Orden', 'alexandria-conversation-builder' );
		$columns['date'] = __( 'Date' );
		return $columns;
	}

	// Add the data to the custom columns for the tonos post type:
	function custom_tonos_column( $column, $post_id ) {

		switch ( $column ) {

			case 'background_color' :
			$color = get_post_meta( $post_id, 'background_color', true );
			echo '<span style="background-color: '.$color.'; width:22px;height:22px;display:block;"></span>';
			break;
			case 'order' :
			echo $order = get_post_meta( $post_id, 'order', true );
			break;
			case 'date' :
			echo $date = get_post_meta( $post_id, 'date', true );
			break;

		}
	}

	/**
	 * Adds "Order" button on module list page
	 */
	function add_order_button_on_list_page()
	{
		global $current_screen;

	    // Not our post type, exit earlier
	    // You can remove this if condition if you don't have any specific post type to restrict to. 
		if ('tonos' != $current_screen->post_type) {
			return;
		}

		?>
		<script type="text/javascript">
			jQuery(document).ready( function($)
			{
				jQuery(".alignleft.actions.bulkactions").append("<a href='#' class='alexandria_tonos_order_button button action'>Ordernar</a>");
			});
		</script>
		<?php
	}

	function order_column_register_sortable($columns){
		$columns['order'] = 'order';
		return $columns;
	}

	function set_custom_tonos_admin_order($wp_query) {

		if (is_admin()) {

			$post_type = $wp_query->query['post_type'];

			if ($post_type == 'tonos') {

				$wp_query->set('order', 'ASC');
				$wp_query->set('meta_key', 'order');
				$wp_query->set('orderby', 'meta_value_num');
				
			}

		}

	}

}