<?php

/**
* The public-facing functionality of the plugin.
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 	Alexandria_Conversation_builder
* @subpackage 	Alexandria_Conversation_builder/public
*/

class Alexandria_Conversation_Builder_Public {

	/**
	 * The plugin options.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$options    The plugin options.
	 */
	private $options;

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$Alexandria_Conversation_Builder 	The name of the plugin.
	 * @param 		string 			$version 			The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		define( 'ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL', plugin_dir_url( __FILE__ ));

		$this->set_options();
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/'.$this->plugin_name.'-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( 'builder', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-builder.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( 'form-steps', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-form-steps.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( 'init', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-init.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-public.js', array( 'jquery' ), $this->version, true  );

		$translated_form_messages = array(
			'images_path' => ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL,

			'no_objective_text' => __( 'La conversación no tiene Objetivo', $this->plugin_name ),
			'no_objective_description_text'   => __( 'El objetivo no tiene descripción', $this->plugin_name ),

			'no_soliloquios_text' => __( 'La conversación no tiene Soliloquios', $this->plugin_name ),
			'no_conclusions_text' => __( 'La conversación no tiene Conclusión', $this->plugin_name ),
			'no_decisions_text' => __( 'La conversación no tiene Decisión', $this->plugin_name ),
			'no_expect_results_text' => __( 'La conversación no tiene Resultado Esperado', $this->plugin_name ),

			'no_relevance_text' => __( 'La conversación no tiene Relevancia', $this->plugin_name ),
			'no_arguments_text' => __( 'La conversación no tiene Argumentos', $this->plugin_name ),
			'no_viable_minimal_text' => __( 'La conversación no tiene Mínimo Viable', $this->plugin_name ),
			'no_comments_text' => __( 'La conversación no tiene Comentarios', $this->plugin_name ),
			'no_strong_questions_text' => __( 'La conversación no tiene Preguntas Potentes', $this->plugin_name ),
			'video_not_support_text' => __( 'Su navegador no soporta la etiqueta de vídeo.', $this->plugin_name ),

			'example_title' => __( 'Ejemplos', $this->plugin_name ),
			'no_example_text' => __( 'La conversación no tiene Ejemplos', $this->plugin_name ),
			'no_example_description_text'   => __( 'El Ejemplo no tiene descripción', $this->plugin_name ),		
		);

		wp_localize_script( 'builder', 'translated_strings', $translated_form_messages );
		wp_localize_script( 'form-steps', 'translated_strings', $translated_form_messages );
		wp_localize_script( 'init', 'translated_strings', $translated_form_messages );
		wp_localize_script( $this->plugin_name, 'translated_strings', $translated_form_messages );

		wp_enqueue_script( 'builder' );
		wp_enqueue_script( 'form-steps' );
		wp_enqueue_script( 'init' );
		wp_enqueue_script( $this->plugin_name );
		
	}

	/**
	 * Processes shortcode alexandria-mail-builder
	 *
	 * @param   array	$atts		The attributes from the shortcode
	 *
	 * @uses	get_option
	 * @uses	get_layout
	 *
	 * @return	mixed	$output		Output of the buffer
	 */
	public function add_alexandria_conversation_builder_shortcode($atts = array()) {

		do_action('alexandria_conversation_builder_main_template', 'landing_page');

	} // add_alexandria_mail_builder_shortcode()


	/**
	 * Registers all shortcodes at once
	 *
	 * @return [type] [description]
	 */
	public function register_shortcodes() {

		if (is_admin()){ return; }

		
		add_shortcode('alexandria-conversation-builder', array( $this, 'add_alexandria_conversation_builder_shortcode'));
	} // register_shortcodes()
	

	/**
	 * Adds a default single view template for a conversation builder opening
	 *
	 * @param 	string 		$template 		The name of the template
	 * @return 	mixed 						The single template
	 */
	public function single_cpt_template( $template ) {

		global $post;

		$return = $template;

		return $return;

	} // single_cpt_template()

	/**
	 * Sets the class variable $options
	 */
	private function set_options() {

		$this->options = get_option( $this->plugin_name . '-options' );

	} // set_options()

} // class