<?php

/**
 * Conversation Landing Page template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Alexandria_Conversation_Builder
 * @subpackage Alexandria_Conversation_Builder/public/templates
 */

if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly

global $post;

$id = $post->ID;

$protected = SwpmProtection::get_instance();
if ($protected->is_protected($id)){ 
	$auth = SwpmAuth::get_instance();
	$permission = SwpmPermission::get_instance($auth->get('membership_level'));

	if(!SwpmMemberUtils::is_member_logged_in() || !$permission->is_permitted($id)) {
    //User is not logged-in. So don't go forward.
		return 0;
	}
}

$button_bg_color =  get_option( 'button_bg_color' ) ?  get_option( 'button_bg_color' ) : '#6628DD';
$button_text_color = get_option( 'button_text_color' ) ?  get_option( 'button_text_color' ) : '#FFFFFF';
$button_border_color = get_option( 'button_border_color' ) ?  get_option( 'button_border_color' ) : '#6628DD';

$button_bg_hover_color = get_option( 'button_bg_hover_color' ) ?  get_option( 'button_bg_hover_color' ) : '#FFFFFF';
$button_hover_text_color = get_option( 'button_hover_text_color' ) ?  get_option( 'button_hover_text_color' ) : '#6628DD';
$button_hover_border_color = get_option( 'button_hover_border_color' ) ?  get_option( 'button_hover_border_color' ) : '#6628DD';

?>

<style>
	#site-header {
		display: none!important;
	}

	.entry-header {
		display: none!important;
	}

	#site-footer {
		display: none!important;
	}

	.alexandria-title-block::before {
		background-image: url('<?php echo ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL.'assets/images/landing_header.jpg'; ?>');
	}

	#alexandria-title-overlay {
		background-color: #383838;
	}

	.alexandria-start-game-button {
		background-color: <?php echo $button_bg_color; ?>;
		border: 1px solid <?php echo $button_border_color; ?>;
		color: <?php echo $button_text_color; ?>;
	}

	.alexandria-start-game-button:hover {
		background-color: <?php echo $button_bg_hover_color ?>;
		border: 1px solid <?php echo $button_border_hover_color; ?>;
		color: <?php echo $button_hover_text_color; ?>;
	}
</style>

<div id="alexandria-main" class="alexandria-builder-container">

	<div class="alexandria-builder-wrapper">

		<div class="alexandria-title-wrapper">

			<div id="alexandria-title-block" class="alexandria-title-block">

				<div id="alexandria-title-overlay"></div>

				<div class="alexandria-builder-back-button-wrapper">

					<a href="/" id="alexandria-back-button" class="alexandria-builder-back-button" alt="<?php echo _e('Volver', 'alexandria-conversation-builder'); ?>">

						<span class="alexandria-builder-back-button-arrow-icon">
							<img src="<?php echo ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL.'assets/images/arrow-left.svg'; ?>" alt="<?php echo _e('Volver', 'alexandria-conversation-builder'); ?>">
						</span>

						<span>
							<?php echo _e('Volver', 'alexandria-conversation-builder'); ?>
						</span>	

					</a>

				</div>

				<div class="alexandria-builder-title">
					<h2><?php

					$title_portada = __('Alexandria Conversation Builder', 'alexandria-conversation-builder');

					if (get_option("titulo_portada")) {
						$title_portada = get_option( 'titulo_portada' );
					}

					echo $title_portada

					?></h2>
				</div>

				<div class="alexandria-builder-intro-text">
					<p><?php 

					$subtitle_portada = __('Construye tu conversación desafiante con sólo 3 inputs', 'alexandria-conversation-builder');

					if (get_option("subtitulo_portada")) {
						$subtitle_portada = get_option( 'subtitulo_portada' );
					}

					echo $subtitle_portada;

					?></p>
				</div>

				<div class="alexandria-builder-duration">
					<span class="duration-icon">
						<img src="<?php echo ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL.'assets/images/reloj.svg'?>" alt="Clock Icon" />
					</span>
					<span class="duration-text"><?php 

					$time = '00:03';

					if (get_option("tiempo_portada")) {
						$time = get_option( 'tiempo_portada' );
					}
					
					echo alexandria_conversation_builder_parse_time($time);

					?></span>
				</div>

				<div class="alexandria-builder-title-button">
					<button type="button" class="alexandria-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
						<?php echo get_option( 'button_text' ) != '' ? get_option( 'button_text' ) : 'Construye conversación'; ?>
					</button>
				</div>

			</div>

		</div>

		<div class="alexandria-builder__body-block">

			<div class="alexandria-builder__description">
				<span><?php _e('Descripción', 'alexandria-conversation-builder' ); ?></span>
				<p>
					<?php 

					$descripcion_portada = __('Construye tu conversación desafiante con sólo 3 inputs', 'alexandria-conversation-builder');

					if (get_option("descripcion_portada")) {
						$descripcion_portada = get_option( 'descripcion_portada' );
					}

					echo $descripcion_portada; 

					?>
				</p>
			</div>

			<div class="alexandria-builder-start-button-wrapper">
				<button type="button" class="alexandria-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
					<?php echo get_option( 'button_text' ) != '' ? get_option( 'button_text' ) : 'Construye conversación'; ?>
				</button>
			</div>

			<!-- Objectives section -->
			<?php include 'elements/objectives-builder.php' ?>

			<div class="alexandria-builder-start-button-wrapper_bottom">
				
				<button type="button" class="alexandria-start-game-button" data-url="<?php echo admin_url('admin-ajax.php')?>">
					<?php echo get_option( 'button_text' ) != '' ? get_option( 'button_text' ) : 'Construye conversación'; ?>
				</button>

			</div>

		</div>

	</div>

</div>

<!-- Contact Modal -->
<?php include 'elements/contact-modal.php' ?>

<!-- Loader section -->
<?php include 'elements/loading-spinner.php' ?>